// Copyright 2007 - 2021, Alan Antonuk and the rabbitmq-c contributors.
// SPDX-License-Identifier: mit

#ifndef AMQP_H
#define AMQP_H

#ifdef _MSC_VER
#   pragma message("warning: amqp.h is deprecated, use rabbitmq-c/amqp.h instead.")
#else
#   warning "amqp.h is deprecated, use rabbitmq-c/amqp.h instead."
#endif

#include <rabbitmq-c/amqp.h>

#endif /* AMQP_H */
